#
# spec file for package python-jenkinsapi
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-jenkinsapi
Version:        0.3.3
Release:        lp151.2.2
Summary:        A Python API for accessing resources on a Jenkins continuous-integration server
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/salimfadhley/jenkinsapi
Source:         https://pypi.io/packages/source/j/jenkinsapi/jenkinsapi-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-pytz >= 2014.4
BuildRequires:  python-requests >= 2.3.0
BuildRequires:  python-setuptools
Requires:       python-pytz >= 2014.4
Requires:       python-requests >= 2.3.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Jenkins is the market leading continuous integration system, originally created
by Kohsuke Kawaguchi.

Jenkins (and It's predecessor Hudson) are useful projects for automating common
development tasks (e.g. unit-testing, production batches) - but they are
somewhat Java-centric. Thankfully the designers have provided an excellent and
complete REST interface. This library wraps up that interface as more 
conventional python objects in order to make many Jenkins oriented tasks
easier to automate.

This library can help you:

 * Query the test-results of a completed build
 * Get a objects representing the latest builds of a job
 * Search for artefacts by simple criteria
 * Block until jobs are complete
 * Install artefacts to custom-specified directory structures
 * username/password auth support for jenkins instances with auth turned on
 * Ability to search for builds by subversion revision
 * Ability to add/remove/query Jenkins slaves
 * Ability to add/remove/modify Jenkins views

%prep
%setup -q -n jenkinsapi-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc README.rst
%{_bindir}/jenkins_invoke
%{_bindir}/jenkinsapi_version
%{python_sitelib}/*

%changelog
* Fri Nov 18 2016 tbechtold@suse.com
- update to 0.3.3:
  * Fixed for Credentials 2.x plugin (#460)
  * Added tests for adding jobs to view (#469)
  * Return full response object if requested on job.update_config method.
  * Adding SSL disabling option, authentication, correction of Java Heap
    setting and some very helpful comments
  * Fixed failing tests on Jenkins 2.0 (#473)
  * Delete build (#493)
  * Decoding bytes with the ISO-8859-1 encoding
  * Removed pypi upload
  * Added coveralls integration
  * When job is invoked with file param http headers will be now set (#494)
  * Adding newline at end of file
  * Adding a note about using an API token as password
  * KrbRequester.get_request_dict missing **kwargs
  * Update setup.cfg to support universal wheels
  * Set version to 0.3.00 and cleaned up a bit
  * Add ssl_verify flag to the Jenkins class
  * Changed jenkins launcher to use pre-built home dir
  * Proper handling of self.url
  * Added SSH node creation and tests
  * Adds correct build information to Build.get_artifacts
  * FIX: allow jenkinsapi to be used without installation
  * And exit 1...
  * working tox configuration for testing/lint with multiple python versions
  * How to kick-off a paramterized build (eg build version, python version)
  * FIX: fix bad indentation (2->4 spaces)
  * Fixed EMPTY_JOB config to match the one returned from Jenkins
  * Now using either wget or curl to download the jenkins.war
  * Fix pylint violations.
  * Revert "Get rid of unused modules and unhelpful comments"
  * Correct the logging format
  * Fix for issue #357
  * Can't find job parameters if in 'property'
  * Restored old way of finding jobs (#477)
  * Fix line spacing
  * Added how_to examples for nodes and credential creation
  * Get rid of unused modules and unhelpful comments
  * pe8, flakes, system-test for safe_restart
  * Fixed pylint errors
  * Added tests for issue #487 (#490)
  * Prepare chunks that are applicable to both Python 2 and 3.
  * Fix 'get_build_by_params' method (#506)
  * adding jenkins.install_plugin, jenkins.install_plugins, and jenkins.safe_restart
  * Removed UTF-8 as a method of decoding the content bytes
  * Categorized view plugin support and change View#add_job approach (#468)
  * Version 0.30.1
  * catch ConnectionError as well as HTTPError while waiting for restart
  * fix typos and lint
  * Version bump prior to release
  * Implement `Secret text` credential (#504)
  * Unified node creation and fixed tests
  * Fix job search (#465)
  * Update setup.py classifiers
  * download artifacts: handle files with special characters
  * Add unit tests of artifact strict validation.
  * In systests.TestNodes.test_get_node_labels make sure the node creation
    code matches the other tests and cleanup the created node when the test
    finishes. Calling jenkins.create_node instead of
    jenkins.nodes.create_node might be the cause of the Travis CI build break.
  * Do not ignore tree parameter to poll
  * [doc] pep8 cleanup of examples in using_jenkinsapi.rst
  * Added required plugins
  * Added codecov, removed coveralls
  * Added issue template
  * Added note that library is not tested on Jenkins 2.0
  * Add Build.get_description()
  * Add ability to retrieve build by params (#488)
  * Cleaned up examples and added example of running job via invoke
  * Update using_jenkinsapi.rst
  * Incremented version
  * Add function to node for querying the labels from the node's config.xml.
    The config.xml querying and caching was copied from the job's config handling code.
  * Job object now able to find job url by asking server
  * Fixed get_config() for jobs returned from view (#478)
  * Moved unit tests to systests
  * Normalized version
  * Manual PEP8 changes
  * Delegated all job operations to Jobs object
  * Fixed url for latest Jenkins version
  * Optimizations to reduce amount of data requested from Jenkins
  * FIX: No longer remove JENKINS_HOME folder when JENKINS_URL is set
  * Add the relative path for artifacts (#497)
  * Fixes #446 and adds check for credential existance before deleting it
  * Fixed broken link in cancel item from queue.
  * Add changes to get slave information
  * Changed all links to point to pycontribs
  * Add a doc regarding ssl_verify arg in the Jenkins class
  * remove testcase which is no longer necessary
  * Added systests for stable and latest Jenkins version
  * Should be echo, not error
  * Fix coding style violations.
  * pyflakes
  * To parameterize the level of fingerprint validation.
  * Added PYPI deploy from travis on new tags
  * Added get_changeset_items() method
  * negotiating python 2 vs 3 differences
  * Moved some unit tests to systests
  * Fix for broken build.stop() function with Jenkins 2.x (#464)
  * fixed python3 compatability
  * Strict artefact systest (#480)
  * Added check for missing "firstBuild" item (#482)
  * Add sudo: false which means we use the new Travis infrastructure
  * Add a warnning message if fingerprints aren't enabled
  * Add support for retrieve info for Label (#459)
  * Added section about Jenkins versions, removed "not tested on Jenkins 2.0"
  * tests for install_plugin and install_plugins
  * add utf8 encoding to support invoking jobs with unicode build params (#500)
  * Added credentials and ssh node creation
  * Make parameterized builds with file params work
  * Added more information about library capabilities
  * Set Jenkins obj to ask server for limited info
  * Added better example for views and fixed bug
  * add tox to gitignore
  * J2x insecure start (#449)
  * Tidy up __init__ and comments
  * Revert "Add sudo: false which means we use the new Travis infrastructure"
  * Changed poll: do not delegate to parent class
  * Added support for ssh credentials
  * Set Jenkins download url to use LTS releases
  * Added CrumbRequester (#479)
  * handle python3 urllib
  * Changes badge and cleaned up TODO
  * Revert "Tidy up __init__ and comments"
  * Adding a why property to a queueitem object (#456)
  * fixing lint
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.2.28:
  * no changelog available
- remove python-nose from build dependency: not needed anymore
- add python-pytz and python-requests as build dependencies
  to ensure their availability
- increase required versions of python-pytz and python-requests
- add jenkinsapi_version binary to the package files
* Fri Jul 11 2014 jw@owncloud.com
- Version bump to 0.2.20
  commit 326b370d084b83ad780569e28dd5ffad908936d1
* Mon Oct 21 2013 speilicke@suse.com
- Initial version
